<?php
/**
 * ngischolarship functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package ngischolarship
 */

if ( ! function_exists( 'victoriastar_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function victoriastar_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on victoriastar, use a find and replace
		 * to change 'victoriastar' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'victoriastar', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__('Main Menu', 'victoriastar'),
			'footer' => esc_html__('Footer Menu', 'victoriastar'),
		) );
		
		

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'victoriastar_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'victoriastar_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function victoriastar_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'victoriastar_content_width', 640 );
}
add_action( 'after_setup_theme', 'victoriastar_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function victoriastar_widgets_init() {
	
	register_sidebar( array(
		'name'          => __( 'MAP', 'victoriastar' ),
		'id'            => 'mapwidget',
		'description'   => __( 'Appears at the bottom of the content on posts and pages.', 'victoriastar' ),
		'before_widget' => '<div>',
		'after_widget'  => '</div>',
	) );
	register_sidebar( array(
		'name'          => __( 'CLIENT TESTIMONIALS', 'victoriastar' ),
		'id'            => 'client_testimonials',
		'description'   => __( 'Appears at the bottom of the content on posts and pages.', 'victoriastar' ),
		'before_widget' => '<div class="item"><div class="testiMonials-slide">',
		'after_widget'  => '</div></div>',
	) );
}
add_action( 'widgets_init', 'victoriastar_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function victoriastar_scripts() {
	//wp_enqueue_style( 'nabilfeed-style', get_stylesheet_uri(), array(), _S_VERSION );
	//wp_style_add_data( 'nabilfeed-style', 'rtl', 'replace' );
	
	wp_enqueue_style('themestyle', get_template_directory_uri() . '/assets/css/style.css', array(), '3.1.6', 'all');
	wp_enqueue_style('responsivestyle', get_template_directory_uri() . '/assets/css/responsive.css', array(), '3.1.6', 'all');
	wp_enqueue_style( 'victoriastar-style', get_stylesheet_uri() );
	
	wp_enqueue_script('jquery');
 //	wp_enqueue_script('victoriastar-script', get_template_directory_uri() . '/assets/js/jquery.min.js', array(), '1.0.7', true);
     wp_enqueue_script('bootstrap-js', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array(), '3.3.7', true);
 	wp_enqueue_script('slicknav-js', get_template_directory_uri() . '/assets/js/jquery.slicknav.js', array(), '3.1.6', true);
 	wp_enqueue_script('owl-arousel-js', get_template_directory_uri() . '/assets/js/owl.carousel.js', array(), '3.1.6', true);
   wp_enqueue_script('custom-js', get_template_directory_uri() . '/assets/js/apps.js', array(), '3.1.6', true);
	wp_enqueue_script( 'victoriastar-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'victoriastar-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'victoriastar_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/*  Option Tree
  --------------------------------------------------------------------------------- */
/*
 * Option Tree
 */

add_filter('ot_theme_mode', '__return_true');
// add_filter('ot_show_pages', '__return_false');
add_filter('ot_show_new_layout', '__return_false');
add_filter('ot_theme_options_parent_slug', '__return_false');

require get_template_directory() . '/option-tree/ot-loader.php';
// require get_template_directory() . '/inc/meta-boxes.php';
require get_template_directory() . '/inc/theme-options.php';

