<?php

/**
 * Initialize the custom Theme Options.
 */
add_action('init', 'shane_custom_theme_options');

/**
 * Build the custom settings & update OptionTree.
 *
 * @return    void
 * @since     2.0
 */
function shane_custom_theme_options() {

    /* OptionTree is not loaded yet, or this is not an admin request */
    if (!function_exists('ot_settings_id') || !is_admin())
        return false;

    /**
     * Get a copy of the saved settings array. 
     */
    $saved_settings = get_option(ot_settings_id(), array());

    /**
     * Custom settings array that will eventually be 
     * passes to the OptionTree Settings API Class.
     */
    $custom_settings = array(
        'sections' => array(
            array(
                'id' => 'general_settings',
                'title' => __('General Settings', 'victoriastar')
            ),
			array(
                'id' => 'banner_settings',
                'title' => __('Home Slider Settings', 'victoriastar')
            ),
            array(
                'id' => 'banner_innerpage_settings',
                'title' => __('Inner Page Slider', 'victoriastar')
            ),
			array(
                'id' => 'homecruises_settings',
                'title' => __('Homepage Settings', 'victoriastar')
            ),
            array(
                'id' => 'rp_settings',
                'title' => __('Recent Projects', 'victoriastar')
            ),     
            array(
                'id' => 'testimonials_settings',
                'title' => __('Testimonials Settings', 'victoriastar')
            ),
            array(
                'id' => 'aboutus_page_settings',
                'title' => __('About Page Settings', 'victoriastar')
            ),
            array(
                'id' => 'services_page_settings',
                'title' => __('Services Page Settings', 'victoriastar')
            ),
			array(
                'id' => 'contact_settings',
                'title' => __('Contact Page Info', 'victoriastar')
            ),
            array(
                'id' => 'footer_settings',
                'title' => __('Footer Settings', 'victoriastar')
            ),
        ),
        'settings' => array(
            /* ------------------ General ------------------- */
            array(
                'id' => 'logo_upload',
                'label' => __('Upload Logo Header', 'victoriastar'),
                'type' => 'upload',
                'section' => 'general_settings',
            ),
            array(
                'id' => 'recent_blog_title',
                'label' => __('Recent Blog - Title', 'victoriastar'),
                'type' => 'text',
                'section' => 'general_settings',
            ),
            array(
                'id' => 'concern_logo_upload_one',
                'label' => __('Concern Logo one', 'victoriastar'),
                'type' => 'upload',
                'section' => 'general_settings',
            ),
            array(
                'id' => 'concern_logo_upload_two',
                'label' => __('Concern Logo two', 'victoriastar'),
                'type' => 'upload',
                'section' => 'general_settings',
            ),
            array(
                'id' => 'concern_logo_upload_three',
                'label' => __('Concern Logo three', 'victoriastar'),
                'type' => 'upload',
                'section' => 'general_settings',
            ),
            array(
                'id' => 'concern_logo_upload_four',
                'label' => __('Concern Logo Four', 'victoriastar'),
                'type' => 'upload',
                'section' => 'general_settings',
            ),
            /* ------------------ Services - Settings ---------------------- */
            array(
                'id' => 'services_page_breadcumbs_cont',
                'label' => __('Breadcumbs Section - Details', 'victoriastar'),
                'type' => 'textarea',
                'section' => 'services_page_settings',
            ),
            array(
                'id' => 'services_page_bottom_cont',
                'label' => __('Bottom Section - Details', 'victoriastar'),
                'type' => 'textarea',
                'section' => 'services_page_settings',
            ),
            /* ------------------ About Us - Settings ---------------------- */
            array(
                'id' => 'counter_details_1',
                'label' => __('Counter Details -1', 'victoriastar'),
                'type' => 'textarea',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'counter_details_2',
                'label' => __('Counter Details -2', 'victoriastar'),
                'type' => 'textarea',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'counter_details_3',
                'label' => __('Counter Details -3', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'counter_details_4',
                'label' => __('Counter Details -4', 'victoriastar'),
                'type' => 'textarea',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'meetTheTeam_title',
                'label' => __('Meet The Team - Title', 'victoriastar'),
                'type' => 'text',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'meetTheTeam_box_1_img',
                'label' => __('Meet The Team - Box IMG -1', 'victoriastar'),
                'type' => 'upload',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'meetTheTeam_box_1',
                'label' => __('Meet The Team - Box -1', 'victoriastar'),
                'type' => 'textarea',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'meetTheTeam_box_2_img',
                'label' => __('Meet The Team - Box IMG -2', 'victoriastar'),
                'type' => 'upload',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'meetTheTeam_box_2',
                'label' => __('Meet The Team - Box -2', 'victoriastar'),
                'type' => 'textarea',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'meetTheTeam_box_3_img',
                'label' => __('Meet The Team - Box IMG -3', 'victoriastar'),
                'type' => 'upload',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'meetTheTeam_box_3',
                'label' => __('Meet The Team - Box -3', 'victoriastar'),
                'type' => 'textarea',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'meetTheTeam_box_4_img',
                'label' => __('Meet The Team - Box IMG -4', 'victoriastar'),
                'type' => 'upload',
                'section' => 'aboutus_page_settings',
            ),
            array(
                'id' => 'meetTheTeam_box_4',
                'label' => __('Meet The Team - Box -4', 'victoriastar'),
                'type' => 'textarea',
                'section' => 'aboutus_page_settings',
            ),
            /* ------------------ Testimonials ---------------------- */
            array(
                'id' => 'testimonials_title',
                'label' => __('Testimonials - Title', 'victoriastar'),
                'type' => 'text',
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_1_img',
                'label' => __('Testimonials - IMG -1', 'victoriastar'),
                'type' => 'upload',
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_1_details',
                'label' => __('Testimonials - Details -1', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_2_img',
                'label' => __('Testimonials - IMG -2', 'victoriastar'),
                'type' => 'upload',
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_2_details',
                'label' => __('Testimonials - Details -2', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_3_img',
                'label' => __('Testimonials - IMG -3', 'victoriastar'),
                'type' => 'upload',
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_3_details',
                'label' => __('Testimonials - Details -3', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_4_img',
                'label' => __('Testimonials - IMG -4', 'victoriastar'),
                'type' => 'upload',
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_4_details',
                'label' => __('Testimonials - Details -4', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_5_img',
                'label' => __('Testimonials - IMG -5', 'victoriastar'),
                'type' => 'upload',
                'section' => 'testimonials_settings',
            ),
            array(
                'id' => 'testiMonials_5_details',
                'label' => __('Testimonials - Details -5', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'testimonials_settings',
            ),
            /* ------------------ Recent Projects ------------------- */
            array(
                'id' => 'rp_title',
                'label' => __('Recent Projects - Title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_vehicles_upload_img',
                'label' => __('Vehicles - IMG', 'victoriastar'),
                'type' => 'upload',
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_vehicles_title',
                'label' => __('Vehicles - Title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_vehicles_details',
                'label' => __('Vehicles - Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_industrial_upload_img',
                'label' => __('Industrial - IMG', 'victoriastar'),
                'type' => 'upload',
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_industrial_title',
                'label' => __('Industrial - Title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_industrial_details',
                'label' => __('Industrial - Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_commercial_upload_img',
                'label' => __('Commercial - IMG', 'victoriastar'),
                'type' => 'upload',
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_commercial_title',
                'label' => __('Commercial - Title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_commercial_details',
                'label' => __('Commercial - Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_biocoal_upload_img',
                'label' => __('Biocoal - IMG', 'victoriastar'),
                'type' => 'upload',
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_biocoal_title',
                'label' => __('Biocoal - Title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_biocoal_details',
                'label' => __('Biocoal - Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_greenCrude_upload_img',
                'label' => __('Green Crude - IMG', 'victoriastar'),
                'type' => 'upload',
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_greenCrude_title',
                'label' => __('Green Crude - Title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_greenCrude_details',
                'label' => __('Green Crude - Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_cleanCooking_upload_img',
                'label' => __('Clean Cooking - IMG', 'victoriastar'),
                'type' => 'upload',
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_cleanCooking_title',
                'label' => __('Clean Cooking - Title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'rp_settings',
            ),
            array(
                'id' => 'rp_cleanCooking_details',
                'label' => __('Clean Cooking - Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'rp_settings',
            ),
            /* ------------------ Home Cruises ------------------- */
            array(
                'id' => 'solutions_title',
                'label' => __('Solutions We Offer title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'homecruises_settings',
            ),
            array(
                'id' => 'solutions_img_upload',
                'label' => __('Solutions We Offer Image', 'victoriastar'),
                'type' => 'upload',
                'section' => 'homecruises_settings',
            ),
            array(
                'id' => 'biochar_details',
                'label' => __('Home Biochar Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'homecruises_settings',
            ),
            array(
                'id' => 'microalgae_details',
                'label' => __('Home Microalgae Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'homecruises_settings',
            ),
			array(
                'id' => 'biocoal_details',
                'label' => __('Home Biocoal Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'homecruises_settings',
            ),
           array(
                'id' => 'industrial_details',
                'label' => __('Home Industrial Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'homecruises_settings',
            ),
            array(
                'id' => 'commercial_details',
                'label' => __('Home Commercial Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'homecruises_settings',
            ),
            array(
                'id' => 'vehicles_details',
                'label' => __('Home Vehicles Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'homecruises_settings',
            ),
            array(
                'id' => 'howitall_upload_img',
                'label' => __('How It All Started - IMG', 'victoriastar'),
                'type' => 'upload',
                'section' => 'homecruises_settings',
            ),
            array(
                'id' => 'howitall_title',
                'label' => __('How It All Started - Title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'homecruises_settings',
            ),
            array(
                'id' => 'howitall_details',
                'label' => __('How It All Started - Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'homecruises_settings',
            ),
            
            array(
                'id' => 'organicEthanol_details',
                'label' => __('Organic Ethanol - Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'homecruises_settings',
            ),
            /* ------------------ Footer ------------------- */
            array(
                'id' => 'footer_logo_upload',
                'label' => __('Upload Footer Logo', 'victoriastar'),
                'type' => 'upload',
                'section' => 'footer_settings',
            ),
            array(
                'id' => 'footerweb_small_details',
                'label' => __('Footer Web Small Details', 'victoriastar'),
                'type' => 'text',                
                'section' => 'footer_settings',
            ),
            array(
                'id' => 'footerweb_address',
                'label' => __('Footer Web Address', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'footer_settings',
            ),
            array(
                'id' => 'facebook_feed',
                'label' => __('Facebook Url', 'victoriastar'),
                'type' => 'text',                
                'section' => 'footer_settings',
            ),
            array(
                'id' => 'youtube_feed',
                'label' => __('Youtube Url', 'victoriastar'),
                'type' => 'text',                
                'section' => 'footer_settings',
            ),
            array(
                'id' => 'twitter_feed',
                'label' => __('Twitter Url', 'victoriastar'),
                'type' => 'text',                
                'section' => 'footer_settings',
            ),
            array(
                'id' => 'linkedin_feed',
                'label' => __('Linkedin Url', 'victoriastar'),
                'type' => 'text',                
                'section' => 'footer_settings',
            ),
            array(
                'id' => 'footer_info',
                'label' => __('Footer Bottom Info', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'footer_settings',
            ),
            /* ------------------ banner Innerpage ---------------*/
            array(
                'id' => 'slider_inn_1_img_upload',
                'label' => __('Slider Inner Page IMG - 1', 'victoriastar'),
                'type' => 'upload',
                'section' => 'banner_innerpage_settings',
            ),
            array(
                'id' => 'slider_inn_1_details',
                'label' => __('Slider Inner Page Details - 1', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'banner_innerpage_settings',
            ),
            array(
                'id' => 'slider_inn_2_img_upload',
                'label' => __('Slider Inner Page IMG - 2', 'victoriastar'),
                'type' => 'upload',
                'section' => 'banner_innerpage_settings',
            ),
            array(
                'id' => 'slider_inn_2_details',
                'label' => __('Slider Inner Page Details - 2', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'banner_innerpage_settings',
            ),
            array(
                'id' => 'slider_inn_3_img_upload',
                'label' => __('Slider Inner Page IMG - 3', 'victoriastar'),
                'type' => 'upload',
                'section' => 'banner_innerpage_settings',
            ),
            array(
                'id' => 'slider_inn_3_details',
                'label' => __('Slider Inner Page Details - 3', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'banner_innerpage_settings',
            ),
            /* ------------------ Home Slider ------------------- */
			array(
                'id' => 'slider_1_img_upload',
                'label' => __('Upload Img Slider 1', 'victoriastar'),
                'type' => 'upload',
                'section' => 'banner_settings',
            ),
            array(
                'id' => 'slider_1_details',
                'label' => __('Slider 1 Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'banner_settings',
            ),
            array(
                'id' => 'slider_1_url',
                'label' => __('Slider 1 button url', 'victoriastar'),
                'type' => 'text',                
                'section' => 'banner_settings',
            ),
            array(
                'id' => 'slider_2_img_upload',
                'label' => __('Upload Img Slider 2', 'victoriastar'),
                'type' => 'upload',
                'section' => 'banner_settings',
            ),
            array(
                'id' => 'slider_2_details',
                'label' => __('Slider 2 Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'banner_settings',
            ),
            array(
                'id' => 'slider_2_url',
                'label' => __('Slider 2 button url', 'victoriastar'),
                'type' => 'text',                
                'section' => 'banner_settings',
            ),
            array(
                'id' => 'slider_3_img_upload',
                'label' => __('Upload Img Slider 3', 'victoriastar'),
                'type' => 'upload',
                'section' => 'banner_settings',
            ),
            array(
                'id' => 'slider_3_details',
                'label' => __('Slider 3 Details', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'banner_settings',
            ),
            array(
                'id' => 'slider_3_url',
                'label' => __('Slider 3 Button url', 'victoriastar'),
                'type' => 'text',                
                'section' => 'banner_settings',
            ),
            /* ------------------ Section Title ------------------- */            
			array(
                'id' => 'client_testimonials_title',
                'label' => __('Banner Title', 'victoriastar'),
                'type' => 'text',                
                'section' => 'section_title_settings',
            ),
			array(
                'id' => 'contact_details',
                'label' => __('Contact Details', 'victoriastar'),
                'type' => 'text',                
                'section' => 'section_title_settings',
            ),
			array(
                'id' => 'location_map',
                'label' => __('Location map', 'victoriastar'),
                'type' => 'text',                
                'section' => 'section_title_settings',
            ),
			array(
                'id' => 'ctoye',
                'label' => __('Get In Touch With Us', 'victoriastar'),
                'type' => 'text',                
                'section' => 'section_title_settings',
            ),            	
			/* ------------------ Contact Page info settings ------------------- */
            array(
                'id' => 'contact_tel',
                'label' => __('Contact Page Phone', 'victoriastar'),
                'type' => 'text',                
                'section' => 'contact_settings',
            ),
            array(
                'id' => 'contact_Fax',
                'label' => __('Contact Page Fax', 'victoriastar'),
                'type' => 'text',                
                'section' => 'contact_settings',
            ),
            array(
                'id' => 'contact_email',
                'label' => __('Contact Page Email', 'victoriastar'),
                'type' => 'text',                
                'section' => 'contact_settings',
            ), 
			
			array(
                'id' => 'contactText',
                'label' => __('Contact Form Heading', 'victoriastar'),
                'type' => 'textarea',                
                'section' => 'contact_settings',
            ),
        )
    );

    /* allow settings to be filtered before saving */
    $custom_settings = apply_filters(ot_settings_id() . '_args', $custom_settings);

    /* settings are not the same update the DB */
    if ($saved_settings !== $custom_settings) {
        update_option(ot_settings_id(), $custom_settings);
    }

    /* Lets OptionTree know the UI Builder is being overridden */
    global $ot_has_custom_theme_options;
    $ot_has_custom_theme_options = true;
}
